@@ -9,8 +9,9 @@ use Daemon::Device;
 use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
+use Date::Format 'time2str';
 
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 sub new {
     my $class = shift;
@@ -69,6 +70,22 @@ sub run {
     $self->{device}->run;
 }
 
+sub note {
+    my ( $self, $msg, $err ) = @_;
+    chomp($msg);
+    $msg = '[' . time2str( '%d/%b/%Y:%H:%M:%S %z', time() ) . '] ' . $msg . "\n";
+
+    if ($err) {
+        die $msg if ( $err eq 'die' );
+        warn $msg;
+    }
+    else {
+        print $msg;
+    }
+
+    return;
+}
+
 sub _parent {
     my ($device) = @_;
     my $self     = $device->data('self');
@@ -95,12 +112,15 @@ sub _parent {
         );
     };
 
+    local $SIG{__WARN__} = sub { note( undef, $_[0], 'warn' ) };
+    local $SIG{__DIE__}  = sub { note( undef, $_[0], 'die'  ) };
+
     srand();
     my @lines;
 
     eval {
         while ( my $line = $self->{socket}->getline ) {
-            print $line;
+            $self->note($line);
             chomp($line);
 
             if ( not $session->{established} ) {
@@ -136,7 +156,7 @@ sub _parent {
                 $delegate->($line);
             }
             else {
-                print "### Skipped repeated line: $line\n";
+                $self->note("### Skipped repeated line: $line");
             }
 
             push @lines, { line => $line, time => $now };
@@ -147,6 +167,9 @@ sub _parent {
 }
 
 sub _child {
+    local $SIG{__WARN__} = sub { note( undef, $_[0], 'warn' ) };
+    local $SIG{__DIE__}  = sub { note( undef, $_[0], 'die'  ) };
+
     srand();
     sleep 1 while (1);
 }
@@ -222,6 +245,9 @@ sub _on_message {
                 );
                 next;
             }
+            elsif ( $self->{in}{text} =~ /Sorry. I don't understand./ ) {
+                next;
+            }
         }
 
         hook: for my $hook (
@@ -232,7 +258,7 @@ sub _on_message {
                 },
                 code => sub {
                     my ( $bot, $in ) = @_;
-                    $bot->reply_to(qq{Sorry. I don't understand. (Try "$bot->{nick} help" for help.)});
+                    $bot->reply_to(qq{Sorry. I don't understand. (Try "$self->{nick} help" for help.)});
                 },
             },
         ) {
@@ -277,6 +303,7 @@ sub load {
                     'Convert',
                     'Karma',
                     'Math',
+                    'History',
                 );
                 next;
             }
@@ -422,7 +449,7 @@ sub say {
 
     for (@_) {
         $self->{socket}->print( $_ . "\r\n" );
-        print '<<< ', $_, "\n";
+        $self->note("<<< $_");
     }
     return $self;
 }
@@ -505,7 +532,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
@@ -1069,6 +1096,21 @@ This method returns a hashref of simple key value pairs for different "health"
 aspects (or current state) of the bot. It includes things like server and port
 connection, number of children, and so on.
 
+=head2 note
+
+While in theory you shouldn't ever need to use it, there is a method called
+"note" which is a handler for writing to the log and error files. If you
+C<warn> or C<die>, this handler steps in automatically. If you'd like to
+C<print> to STDOUT, which you really shouldn't need to do, then it's best to
+call this method instead. The reason being is that the log file is designed to
+be parsed in a specific way. If you write whatever you want to it, it will
+corrupt the log file. That said, if you really, really want to, here's how you
+use C<note>:
+
+    $bot->note('Message');           # writes a message to the log file
+    $bot->note( 'Message', 'warn' ); # writes a message to the error file
+    $bot->note( 'Message', 'die' );  # writes a message to the error file the dies
+
 =head1 SEE ALSO
 
 You can look for additional information at:
