@@ -7,10 +7,11 @@ use warnings;
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 sub init {
     my ($bot) = @_;
+    my $greeting = $bot->{vars}{greeting} // 'greetings';
 
     $bot->hook(
         {
@@ -18,25 +19,50 @@ sub init {
         },
         sub {
             my ( $bot, $in ) = @_;
-
-            my $greeting = $bot->{vars}{greeting} // 'greetings';
-
-            if ( $in->{nick} !~ /[a-z]/ ) {
-                $greeting = uc($greeting);
-            }
-            else {
-                for ( my $i = 0; $i < length($greeting) and $i < length( $in->{nick} ); $i++ ) {
-                    my $letter = substr( $in->{nick}, $i, 1 );
-                    substr( $greeting, $i, 1, uc( substr( $greeting, $i, 1 ) ) ) if ( $letter =~ /[A-Z]/ );
-                }
-            }
-            $greeting =~ tr/oi/01/ if ( $in->{nick} =~ /[0-9]/ );
-            $greeting .= $1 if ( $in->{nick} =~ /(_+)$/ );
-
-            $bot->reply_to($greeting);
+            $bot->reply_to( greeting_based_on_nick( $greeting, $in->{nick} ) );
             return;
         },
     );
+
+    $bot->hook(
+        {
+            to_me => 1,
+            text  => greeting_based_on_nick( $greeting, $bot->nick ),
+        },
+        sub {
+            my ( $bot, $in ) = @_;
+            $bot->reply_to('Thanks.');
+        },
+    );
+
+    $bot->hook(
+        {
+            to_me => 1,
+            text  => 'Thanks.',
+        },
+        sub {
+            my ( $bot, $in ) = @_;
+            $bot->reply_to(q{You're welcome.});
+        },
+    );
+}
+
+sub greeting_based_on_nick {
+    my ( $greeting, $nick ) = @_;
+
+    if ( $nick !~ /[a-z]/ ) {
+        $greeting = uc($greeting);
+    }
+    else {
+        for ( my $i = 0; $i < length($greeting) and $i < length( $nick ); $i++ ) {
+            my $letter = substr( $nick, $i, 1 );
+            substr( $greeting, $i, 1, uc( substr( $greeting, $i, 1 ) ) ) if ( $letter =~ /[A-Z]/ );
+        }
+    }
+    $greeting =~ tr/oi/01/ if ( $nick =~ /[0-9]/ );
+    $greeting .= $1 if ( $nick =~ /(_+)$/ );
+
+    return $greeting;
 }
 
 1;
@@ -53,7 +79,7 @@ Bot::IRC::Greeting - Bot::IRC greet joining users to channels
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -79,7 +105,7 @@ You can specify the greeting word with C<vars>, C<greeting>.
 
 L<Bot::IRC>
 
-=for Pod::Coverage init
+=for Pod::Coverage init greeting_based_on_nick
 
 =head1 AUTHOR
 
